========================
Materia Structure Module
========================

.. begin-description

.. image:: https://codecov.io/gh/kijanac/materia-structure/branch/main/graph/badge.svg
  :target: https://codecov.io/gh/kijanac/materia-structure

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github

**Streamlined interface for managing atomistic structure data.**

Streamlined interface for managing atomistic structure data through Materia. Defines unified and intuitive functionality for manipulating atomistic structure data leveraging the power of Openbabel.

.. end-description

---------------
Getting Started
---------------

Installing
----------
.. begin-installing

From `pip <https://pypi.org/project/materia-structure/>`_:

``pip install materia-structure``

From `conda <https://anaconda.org/kijana/materia-structure>`_:

``conda install -c conda-forge -c kijana materia-structure``

.. end-installing

Documentation
-------------
See documentation `here <https://kijanac.github.io/materia-structure/>`_.

Examples
--------
See example scripts in `Examples <https://github.com/kijanac/materia-structure/tree/main/examples>`_.

.. begin-about

-------
Authors
-------
Ki-Jana Carter

-------
License
-------
This project is licensed under the MIT License - see the `LICENSE <https://github.com/kijanac/materia-structure/blob/main/LICENSE>`_ file for details.

.. end-about

.. begin-contributing

------------
Contributing
------------
See `CONTRIBUTING <https://github.com/kijanac/materia-structure/blob/main/CONTRIBUTING.rst>`_.

.. end-contributing